# Total-Connect-Client
Total-Connect-Client is a super simple python client for interacting with TotalConnect2 alarm system.

Currently this library only supports arming (away, stay, and night), disarming and getting panel status. I wrote this mostly to add alarm support for my personal HomeAssistant set-up, but if there is demand for more functionality I can look into adding it.
